==> inkline-inkline-4.0.0-rc.31.tgz: package/README.md <==
<p align="center">
    <a href="https://inkline.io/">
        <img src="https://raw.githubusercontent.com/inkline/inkline.io/main/assets/images/logo/logo-black.svg" alt="Inkline" width=72 height=72>
    </a>
</p>

<h1 align="center">Inkline</h1>

<p align="center">
    Inkline is the intuitive UI Components library that gives you a developer-friendly foundation for building high-quality, accessible, and customizable Vue.js 3 Design Systems.<br/><br/> Inkline is written and maintained by <a href="https://github.com/alexgrozav">@alexgrozav</a>.
    <br/>
    <br/>
    <br/>
    <a href="https://inkline.io">
        <img src="https://raw.githubusercontent.com/inkline/inkline.io/main/assets/images/github/homepage.png" width="1009" alt="Vue.js UI/UX Library - Inkline" />
    </a>
    <br/>
    <br/>
    <br/>
    <a href="https://inkline.io">Homepage</a>
    ·
    <a href="https://inkline.io/docs/introduction">Documentation</a>
    ·
    <a href="https://storybook.inkline.io/">Storybook</a>
    ·
    <a href="https://stackblitz.com/edit/inkline?file=src/App.vue">Playground</a>
    ·
    <a href="https://github.com/inkline/inkline/issues">Issue Tracker</a>
</p>

<br/>

<p align="center">
    <a href="https://www.npmjs.com/package/@inkline/inkline">
        <img src="https://img.shields.io/npm/v/@inkline/inkline.svg" alt="npm version">
    </a>
    <a href="https://github.com/inkline/inkline/actions">
        <img src="https://github.com/inkline/inkline/workflows/Build/badge.svg" alt="Build">
    </a>
    <a href='https://coveralls.io/github/inkline/inkline?branch=main'><img src='https://coveralls.io/repos/github/inkline/inkline/badge.svg?branch=main' alt='Coverage Status' /></a>
    <a href="https://www.npmjs.com/package/@inkline/inkline">
        <img src="https://img.shields.io/npm/dm/@inkline/inkline.svg" alt="Downloads">
    </a>
    <a href="https://chat.inkline.io">
        <img src="https://img.shields.io/discord/550436704482492429.svg" alt="Discord">
    </a>
</p>

<br/>
<br/>

## Table of contents

-   [Installation](#installation)
-   [Bugs and feature requests](#bugs-and-feature-requests)
-   [Contributing](#contributing)
-   [Community](#community)
-   [Releases](#releases)
-   [Versioning](#versioning)
-   [Creator](#creator)
-   [Copyright and license](#copyright-and-license)

## Installation

Read the [Getting Started guide](https://inkline.io/docs/introduction) or choose one of the guides
below. Inkline offers official integrations for Vite.js (recommended), Vue.js CLI and Nuxt.js, but
can be easily installed for a custom Vue.js configuration as well.

<a href="https://inkline.io/docs/introduction/installation/vite">
    <img src="https://raw.githubusercontent.com/inkline/inkline.io/main/assets/images/github/installation-vitejs.png" width="526" alt="Nuxt.js Installation - Inkline" />
</a>

<a href="https://inkline.io/docs/introduction/installation/vue-cli">
    <img src="https://raw.githubusercontent.com/inkline/inkline.io/main/assets/images/github/installation-vuejs.png" width="526" alt="Vue CLI Installation - Inkline" />
</a>

<a href="https://inkline.io/docs/introduction/installation/nuxt">
    <img src="https://raw.githubusercontent.com/inkline/inkline.io/main/assets/images/github/installation-nuxtjs.png" width="526" alt="Nuxt.js Installation - Inkline" />
</a>

<a href="https://inkline.io/docs/introduction/installation/generic">
    <img src="https://raw.githubusercontent.com/inkline/inkline.io/main/assets/images/github/installation-generic.png" width="526" alt="Custom Installation - Inkline" />
</a>

<a href="https://inkline.io/docs/introduction/installation/cdn">
    <img src="https://raw.githubusercontent.com/inkline/inkline.io/main/assets/images/github/installation-cdn.png" width="526" alt="CDN Installation - Inkline" />
</a>

## Bugs and feature requests

Have a bug or a feature request? Please first search for existing and closed issues. If your problem
or idea is not addressed yet,
[please open a new issue](https://github.com/inkline/inkline/issues/new).

## Community

Get updates on Inkline's development and chat with the project maintainers and community members.

-   Follow [@inkline on Twitter](https://twitter.com/inkline).
-   Join [Inkline on Discord](https://chat.inkline.io).
-   Developers should use the keyword `inkline` on packages which modify or add to the functionality
    of Inkline when distributing through [npm](https://www.npmjs.com/browse/keyword/inkline) or
    similar delivery mechanisms for maximum discoverability.

## Releases

[Previous releases](https://github.com/inkline/inkline/releases) and their documentation are also
available for download.

## Versioning

For increased transparency and backward compatibility, Inkline is maintained under
[the Semantic Versioning guidelines](https://semver.org/).

## Creator

### **Alex Grozav**

-   <https://grozav.com>
-   <https://twitter.com/alexgrozav>
-   <https://facebook.com/alexgrozav>
-   <https://github.com/alexgrozav>

If you use Inkline in your daily work and feel that it has made your life easier, please consider
sponsoring me on [Github Sponsors](https://github.com/sponsors/alexgrozav). 💖

## Contributing

Please read through our [contributing guidelines](./.github/CONTRIBUTING.md). There you can find
directions for opening issues, feature requests, coding standards, and how to setup a local
development environment.

Thanks goes to these wonderful people:

<!-- ALL-CONTRIBUTORS-LIST:START - Do not remove or modify this section -->
<!-- prettier-ignore-start -->
<!-- markdownlint-disable -->
<table>
  <tbody>
    <tr>
      <td align="center" valign="top" width="10%"><a href="https://github.com/alexgrozav"><img class="avatar" src="https://avatars3.githubusercontent.com/u/6179477?v=4" width="50px;" alt="Alex Grozav"/></a></td>
      <td align="center" valign="top" width="10%"><a href="https://github.com/mtancoigne"><img class="avatar" src="https://avatars3.githubusercontent.com/u/1732268?v=4" width="50px;" alt="Manuel Tancoigne"/></a></td>
      <td align="center" valign="top" width="10%"><a href="https://github.com/renielDev"><img class="avatar" src="https://avatars1.githubusercontent.com/u/14147493?v=4" width="50px;" alt="Reniel Salvador"/></a></td>
      <td align="center" valign="top" width="10%"><a href="https://github.com/TheJaredWilcurt"><img class="avatar" src="https://avatars1.githubusercontent.com/u/4629794?v=4" width="50px;" alt="The Jared Wilcurt"/></a></td>
      <td align="center" valign="top" width="10%"><a href="https://github.com/Eternal-Rise"><img class="avatar" src="https://avatars2.githubusercontent.com/u/34982358?v=4" width="50px;" alt="Bogdan Saliuk"/></a></td>
      <td align="center" valign="top" width="10%"><a href="https://github.com/marbocub"><img class="avatar" src="https://avatars3.githubusercontent.com/u/1912821?v=4" width="50px;" alt="marbocub"/></a></td>
      <td align="center" valign="top" width="10%"><a href="https://dimitrio.dev/"><img class="avatar" src="https://avatars3.githubusercontent.com/u/16154728?v=4" width="50px;" alt="Dimitrios Mandamadiotis"/></a></td>
      <td align="center" valign="top" width="10%"><a href="https://github.com/roiLeo"><img class="avatar" src="https://avatars1.githubusercontent.com/u/9987732?v=4" width="50px;" alt="roiLeo"/></a></td>
      <td align="center" valign="top" width="10%"><a href="https://github.com/milaan-muc"><img class="avatar" src="https://avatars.githubusercontent.com/u/3469112?v=4" width="50px;" alt="milaan-muc"/></a></td>
      <td align="center" valign="top" width="10%"><a href="https://github.com/masihtak"><img class="avatar" src="https://avatars.githubusercontent.com/u/4639192?v=4" width="50px;" alt="Masih Abjadi"/></a></td>
    </tr>
    <tr>
      <td align="center" valign="top" width="10%"><a href="https://github.com/IDisposable"><img class="avatar" src="https://avatars.githubusercontent.com/u/874059?v=4" width="50px;" alt="Marc Brooks"/></a></td>
      <td align="center" valign="top" width="10%"><a href="https://github.com/onno-timmerman"><img class="avatar" src="https://avatars.githubusercontent.com/u/178425?v=4" width="50px;" alt="code-on"/></a></td>
      <td align="center" valign="top" width="10%"><a href="https://github.com/agarbutt"><img class="avatar" src="https://avatars.githubusercontent.com/u/734757?v=4" width="50px;" alt="Andrew Garbutt"/></a></td>
      <td align="center" valign="top" width="10%"><a href="https://github.com/skyroses"><img class="avatar" src="https://avatars.githubusercontent.com/u/46625964?v=4" width="50px;" alt="Kamil"/></a></td>
      <td align="center" valign="top" width="10%"><a href="https://github.com/FerroEduardo"><img class="avatar" src="https://avatars.githubusercontent.com/u/47820549?v=4" width="50px;" alt="Eduardo Cabral"/></a></td>
      <td align="center" valign="top" width="10%"><a href="https://github.com/joewelds"><img class="avatar" src="https://avatars.githubusercontent.com/u/28027932?v=4" width="50px;" alt="Joe"/></a></td>
      <td align="center" valign="top" width="10%"><a href="https://github.com/simondib"><img class="avatar" src="https://avatars.githubusercontent.com/u/7483506?v=4" width="50px;" alt="Simon"/></a></td>
      <td align="center" valign="top" width="10%"><a href="https://github.com/thunfisch987"><img class="avatar" src="https://avatars.githubusercontent.com/u/43795814?v=4" width="50px;" alt="thunfisch987"/></a></td>
      <td align="center" valign="top" width="10%"><a href="https://github.com/theruziev"><img class="avatar" src="https://avatars.githubusercontent.com/u/32102033?v=4" width="50px;" alt="Bakhtiyor Ruziev"/></a></td>
      <td align="center" valign="top" width="10%"><a href="https://pkej.github.io/"><img class="avatar" src="https://avatars.githubusercontent.com/u/7883794?v=4" width="50px;" alt="Paul Kenneth Egell-Johnsen"/></a></td>
    </tr>
  </tbody>
</table>

<!-- markdownlint-restore -->
<!-- prettier-ignore-end -->

<!-- ALL-CONTRIBUTORS-LIST:END -->

## Copyright and license

Code copyright 2017-2022 [Inkline Authors](https://github.com/inkline/inkline/graphs/contributors).
Code released under the
[MIT License](https://github.com/inkline/inkline/blob/main/packages/inkline/LICENSE).

==> inkline-inkline-4.7.1.tgz: package/README.md <==
<p align="center">
    <a href="https://inkline.io/">
        <img src="https://www.inkline.io/assets/images/logo/logo-black.svg" alt="Inkline" width=72 height=72>
    </a>
</p>

<h1 align="center">Inkline</h1>

<p align="center">
    Inkline is the intuitive UI Components library that gives you a developer-friendly foundation for building high-quality, accessible, and customizable Vue.js 3 Design Systems.<br/><br/> Inkline is written and maintained by <a href="https://github.com/alexgrozav">@alexgrozav</a>.
    <br/>
    <br/>
    <br/>
    <a href="https://inkline.io">
        <img src="https://www.inkline.io/assets/images/github/homepage.png" width="1009" alt="Vue.js UI/UX Library - Inkline" />
    </a>
    <br/>
    <br/>
    <br/>
    <a href="https://inkline.io">Homepage</a>
    ·
    <a href="https://inkline.io/docs/introduction">Documentation</a>
    ·
    <a href="https://storybook.inkline.io/">Storybook</a>
    ·
    <a href="https://stackblitz.com/edit/inkline?file=src/App.vue">Playground</a>
    ·
    <a href="https://github.com/inkline/inkline/issues">Issue Tracker</a>
</p>

<br/>

<p align="center">
    <a href="https://www.npmjs.com/package/@inkline/inkline">
        <img src="https://img.shields.io/npm/v/@inkline/inkline.svg" alt="npm version">
    </a>
    <a href="https://github.com/inkline/inkline/actions">
        <img src="https://github.com/inkline/inkline/workflows/Build/badge.svg" alt="Build">
    </a>
    <a href='https://coveralls.io/github/inkline/inkline?branch=main'><img src='https://coveralls.io/repos/github/inkline/inkline/badge.svg?branch=main' alt='Coverage Status' /></a>
    <a href="https://www.npmjs.com/package/@inkline/inkline">
        <img src="https://img.shields.io/npm/dm/@inkline/inkline.svg" alt="Downloads">
    </a>
    <a href="https://chat.inkline.io">
        <img src="https://img.shields.io/discord/550436704482492429.svg" alt="Discord">
    </a>
</p>

<br/>
<br/>

## Table of contents

-   [Installation](#installation)
-   [Bugs and feature requests](#bugs-and-feature-requests)
-   [Contributing](#contributing)
-   [Community](#community)
-   [Releases](#releases)
-   [Versioning](#versioning)
-   [Creator](#creator)
-   [Copyright and license](#copyright-and-license)

## Installation

Read the [Getting Started guide](https://inkline.io/docs/introduction) or choose one of the guides
below. Inkline offers official integrations for Vite.js (recommended), Vue.js CLI and Nuxt.js, but
can be easily installed for a custom Vue.js configuration as well.

<a href="https://inkline.io/docs/installation/vite">
    <img src="https://www.inkline.io/assets/images/github/installation-vitejs.png" width="526" alt="Nuxt.js Installation - Inkline" />
</a>

<a href="https://inkline.io/docs/installation/nuxt">
    <img src="https://www.inkline.io/assets/images/github/installation-nuxtjs.png" width="526" alt="Nuxt.js Installation - Inkline" />
</a>

<a href="https://inkline.io/docs/installation/webpack">
    <img src="https://www.inkline.io/assets/images/github/installation-vuejs.png" width="526" alt="Vue CLI Installation - Inkline" />
</a>

<a href="https://inkline.io/docs/installation/manual">
    <img src="https://www.inkline.io/assets/images/github/installation-generic.png" width="526" alt="Custom Installation - Inkline" />
</a>

<a href="https://inkline.io/docs/installation/cdn">
    <img src="https://www.inkline.io/assets/images/github/installation-cdn.png" width="526" alt="CDN Installation - Inkline" />
</a>

## Bugs and feature requests

Have a bug or a feature request? Please first search for existing and closed issues. If your problem
or idea is not addressed yet,
[please open a new issue](https://github.com/inkline/inkline/issues/new).

## Community

Get updates on Inkline's development and chat with the project maintainers and community members.

-   Follow [@inkline on Twitter](https://twitter.com/inkline).
-   Join [Inkline on Discord](https://chat.inkline.io).
-   Developers should use the keyword `inkline` on packages which modify or add to the functionality
    of Inkline when distributing through [npm](https://www.npmjs.com/browse/keyword/inkline) or
    similar delivery mechanisms for maximum discoverability.

## Releases

[Previous releases](https://github.com/inkline/inkline/releases) and their documentation are also
available for download.

## Versioning

For increased transparency and backward compatibility, Inkline is maintained under
[the Semantic Versioning guidelines](https://semver.org/).

## Creator

### **Alex Grozav**

-   <https://grozav.com>
-   <https://twitter.com/alexgrozav>
-   <https://facebook.com/alexgrozav>
-   <https://github.com/alexgrozav>

If you use Inkline in your daily work and feel that it has made your life easier, please consider
sponsoring me on [Github Sponsors](https://github.com/sponsors/alexgrozav). 💖

## Contributing

Please read through our [contributing guidelines](./.github/CONTRIBUTING.md). There you can find
directions for opening issues, feature requests, coding standards, and how to setup a local
development environment.

Thanks goes to these wonderful people:

<!-- ALL-CONTRIBUTORS-LIST:START - Do not remove or modify this section -->
<!-- prettier-ignore-start -->
<!-- markdownlint-disable -->
<table>
  <tbody>
    <tr>
      <td align="center" valign="top" width="10%"><a href="https://github.com/alexgrozav"><img class="avatar" src="https://avatars3.githubusercontent.com/u/6179477?v=4" width="50px;" alt="Alex Grozav"/></a></td>
      <td align="center" valign="top" width="10%"><a href="https://github.com/mtancoigne"><img class="avatar" src="https://avatars3.githubusercontent.com/u/1732268?v=4" width="50px;" alt="Manuel Tancoigne"/></a></td>
      <td align="center" valign="top" width="10%"><a href="https://github.com/renielDev"><img class="avatar" src="https://avatars1.githubusercontent.com/u/14147493?v=4" width="50px;" alt="Reniel Salvador"/></a></td>
      <td align="center" valign="top" width="10%"><a href="https://github.com/TheJaredWilcurt"><img class="avatar" src="https://avatars1.githubusercontent.com/u/4629794?v=4" width="50px;" alt="The Jared Wilcurt"/></a></td>
      <td align="center" valign="top" width="10%"><a href="https://github.com/Eternal-Rise"><img class="avatar" src="https://avatars2.githubusercontent.com/u/34982358?v=4" width="50px;" alt="Bogdan Saliuk"/></a></td>
      <td align="center" valign="top" width="10%"><a href="https://github.com/marbocub"><img class="avatar" src="https://avatars3.githubusercontent.com/u/1912821?v=4" width="50px;" alt="marbocub"/></a></td>
      <td align="center" valign="top" width="10%"><a href="https://dimitrio.dev/"><img class="avatar" src="https://avatars3.githubusercontent.com/u/16154728?v=4" width="50px;" alt="Dimitrios Mandamadiotis"/></a></td>
      <td align="center" valign="top" width="10%"><a href="https://github.com/roiLeo"><img class="avatar" src="https://avatars1.githubusercontent.com/u/9987732?v=4" width="50px;" alt="roiLeo"/></a></td>
      <td align="center" valign="top" width="10%"><a href="https://github.com/milaan-muc"><img class="avatar" src="https://avatars.githubusercontent.com/u/3469112?v=4" width="50px;" alt="milaan-muc"/></a></td>
      <td align="center" valign="top" width="10%"><a href="https://github.com/masihtak"><img class="avatar" src="https://avatars.githubusercontent.com/u/4639192?v=4" width="50px;" alt="Masih Abjadi"/></a></td>
    </tr>
    <tr>
      <td align="center" valign="top" width="10%"><a href="https://github.com/IDisposable"><img class="avatar" src="https://avatars.githubusercontent.com/u/874059?v=4" width="50px;" alt="Marc Brooks"/></a></td>
      <td align="center" valign="top" width="10%"><a href="https://github.com/onno-timmerman"><img class="avatar" src="https://avatars.githubusercontent.com/u/178425?v=4" width="50px;" alt="code-on"/></a></td>
      <td align="center" valign="top" width="10%"><a href="https://github.com/agarbutt"><img class="avatar" src="https://avatars.githubusercontent.com/u/734757?v=4" width="50px;" alt="Andrew Garbutt"/></a></td>
      <td align="center" valign="top" width="10%"><a href="https://github.com/skyroses"><img class="avatar" src="https://avatars.githubusercontent.com/u/46625964?v=4" width="50px;" alt="Kamil"/></a></td>
      <td align="center" valign="top" width="10%"><a href="https://github.com/FerroEduardo"><img class="avatar" src="https://avatars.githubusercontent.com/u/47820549?v=4" width="50px;" alt="Eduardo Cabral"/></a></td>
      <td align="center" valign="top" width="10%"><a href="https://github.com/joewelds"><img class="avatar" src="https://avatars.githubusercontent.com/u/28027932?v=4" width="50px;" alt="Joe"/></a></td>
      <td align="center" valign="top" width="10%"><a href="https://github.com/simondib"><img class="avatar" src="https://avatars.githubusercontent.com/u/7483506?v=4" width="50px;" alt="Simon"/></a></td>
      <td align="center" valign="top" width="10%"><a href="https://github.com/thunfisch987"><img class="avatar" src="https://avatars.githubusercontent.com/u/43795814?v=4" width="50px;" alt="thunfisch987"/></a></td>
      <td align="center" valign="top" width="10%"><a href="https://github.com/theruziev"><img class="avatar" src="https://avatars.githubusercontent.com/u/32102033?v=4" width="50px;" alt="Bakhtiyor Ruziev"/></a></td>
      <td align="center" valign="top" width="10%"><a href="https://pkej.github.io/"><img class="avatar" src="https://avatars.githubusercontent.com/u/7883794?v=4" width="50px;" alt="Paul Kenneth Egell-Johnsen"/></a></td>
    </tr>
    <tr>
      <td align="center" valign="top" width="10%"><a href="https://github.com/intjelic"><img class="avatar" src="https://avatars.githubusercontent.com/u/778121?v=4" width="50px;" alt="Jonathan De Wachter"/></a></td>
      <td align="center" valign="top" width="10%"><a href="https://github.com/zozulinskyi"><img class="avatar" src="https://avatars.githubusercontent.com/u/11585924?v=4" width="50px;" alt="IHOR"/></a></td>
      <td align="center" valign="top" width="10%"><a href="https://github.com/Timbological"><img class="avatar" src="https://avatars.githubusercontent.com/u/31364357?v=4" width="50px;" alt="Timbological"/></a></td>
      <td align="center" valign="top" width="10%"><a href="https://github.com/aileen-r"><img class="avatar" src="https://avatars.githubusercontent.com/u/38075097?v=4" width="50px;" alt="Aileen Rae"/></a></td>
      <td align="center" valign="top" width="10%"><a href="https://github.com/GMKR"><img class="avatar" src="https://avatars.githubusercontent.com/u/2089640?v=4" width="50px;" alt="Mohan G"/></a></td>
      <td align="center" valign="top" width="10%"><a href="https://github.com/Curetix"><img class="avatar" src="https://avatars.githubusercontent.com/u/15160542?v=4" width="50px;" alt="Curetix"/></a></td>
    </tr>
  </tbody>
</table>

<!-- markdownlint-restore -->
<!-- prettier-ignore-end -->

<!-- ALL-CONTRIBUTORS-LIST:END -->

## Copyright and license

Code copyright 2017-2022 [Inkline Authors](https://github.com/inkline/inkline/graphs/contributors).
Code released under the
[MIT License](https://github.com/inkline/inkline/blob/main/packages/inkline/LICENSE).
